@@ -41,6 +41,9 @@ type Window struct {
 type Config struct {
 	SendKeysTimeout int    `yaml:"sendkeys_timeout"`
 	Session         string `yaml:"session"`
+	DetachHook	 	string `yaml:"detach_hook"`
+	AttachHook		string `yaml:"attach_hook"`
+
 	// Attach controls whether the session automatically attaches after creation.
 	// The -a/--attach CLI flag can also enable attachment.
 	Attach      bool              `yaml:"attach,omitempty"`
@@ -57,6 +60,10 @@ func addDefaultEnvs(c *Config, path string) {
 	c.Env["SMUG_SESSION_CONFIG_PATH"] = path
 }
 
+func RemoveConfig(path string) error {
+	return os.Remove(path)
+}
+
 func EditConfig(path string) error {
 	editor := os.Getenv("EDITOR")
 	if editor == "" {
