@@ -10,12 +10,14 @@ import (
 )
 
 const (
-	CommandStart = "start"
-	CommandStop  = "stop"
-	CommandNew   = "new"
-	CommandEdit  = "edit"
-	CommandList  = "list"
-	CommandPrint = "print"
+	CommandStart  = "start"
+	CommandStop   = "stop"
+	CommandNew    = "new"
+	CommandEdit   = "edit"
+	CommandList   = "list"
+	CommandPrint  = "print"
+	CommandRemove = "rm"
+	CommandSwitch = "switch"
 )
 
 type command struct {
@@ -44,12 +46,20 @@ var Commands = commands{
 	},
 	{
 		Name:    CommandList,
-		Aliases: []string{"l"},
+		Aliases: []string{"l", "ls"},
 	},
 	{
 		Name:    CommandPrint,
 		Aliases: []string{"p"},
 	},
+	{
+		Name:    CommandRemove,
+		Aliases: []string{"r"},
+	},
+	{
+		Name:    CommandSwitch,
+		Aliases: []string{"sw"},
+	},
 }
 
 func (c *commands) Resolve(v string) (*command, error) {
@@ -163,7 +173,7 @@ func ParseOptions(argv []string) (*Options, error) {
 
 	settings := parseUserSettings(flags.Args()[1:])
 
-	return &Options{
+	opts := &Options{
 		Project:              project,
 		Config:               *config,
 		Command:              cmd.Name,
@@ -173,5 +183,11 @@ func ParseOptions(argv []string) (*Options, error) {
 		Detach:               *detach,
 		Debug:                *debug,
 		InsideCurrentSession: *insideCurrentSession,
-	}, nil
+	}
+
+	if cmd.Name == CommandSwitch {
+		opts.Attach = true
+	}
+
+	return opts, nil
 }
