@@ -4,6 +4,7 @@ import (
 	"os"
 	"os/exec"
 	"strings"
+	"fmt"
 )
 
 const (
@@ -66,9 +67,19 @@ func (tmux Tmux) NewSession(name string, root string, windowName string) (string
 }
 
 func (tmux Tmux) SessionExists(name string) bool {
-	cmd := tmux.cmd("has-session", "-t", name)
+	cmd := tmux.cmd("list-sessions", "-F", "#{session_name}")
 	res, err := tmux.commander.Exec(cmd)
-	return res == "" && err == nil
+	if err != nil {
+		return false
+	}
+
+	name = strings.Trim(name, ":")
+	for _, s := range strings.Split(strings.TrimSpace(res), "\n") {
+		if s == name {
+			return true
+		}
+	}
+	return false
 }
 
 func (tmux Tmux) KillWindow(target string) error {
@@ -210,3 +221,25 @@ func (tmux Tmux) ListPanes(target string) ([]TmuxPane, error) {
 
 	return panes, nil
 }
+
+func (tmux Tmux) SetHook(target string, hookEvent string, command string) error {
+	// for client-detached 0 means last detached client
+	// for client-attached 1 means first attached client
+	var lastOrFirst string
+
+	// only these two hooks for now
+	if hookEvent == "client-detached" {
+		lastOrFirst = "0"
+	} else if hookEvent == "client-attached" {
+		lastOrFirst = "1"
+	} else {
+		return fmt.Errorf("unsupported hook event: %s", hookEvent)
+	}
+
+	hookCondition:= fmt.Sprintf(
+		`if -F "#{==:#{session_attached},%s}" "run-shell \"%s\""`,
+		lastOrFirst, command)
+
+	cmd := tmux.cmd("set-hook", "-t", target, hookEvent, hookCondition)
+	return tmux.commander.ExecSilently(cmd)
+}
